#
# spec file for package python-cliff
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-cliff
Version:        4.8.0
Release:        1.2
Summary:        Command Line Interface Formulation Framework
License:        Apache-2.0
URL:            https://docs.openstack.org/cliff/latest/
Source:         https://files.pythonhosted.org/packages/source/c/cliff/cliff-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module autopage >= 0.4.0}
BuildRequires:  %{python_module PrettyTable >= 0.7.2}
BuildRequires:  %{python_module PyYAML >= 3.12}
BuildRequires:  %{python_module Sphinx >= 2.0.0}
BuildRequires:  %{python_module cmd2 >= 1.0.0}
BuildRequires:  %{python_module coverage >= 4.0}
BuildRequires:  %{python_module fixtures}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module stevedore >= 2.0.1}
BuildRequires:  %{python_module testscenarios >= 0.4}
BuildRequires:  %{python_module testtools >= 2.2.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-PrettyTable >= 0.7.2
Requires:       python-PyYAML >= 3.12
Requires:       python-autopage >= 0.4.0
Requires:       python-cmd2 >= 1.0.0
Requires:       python-stevedore >= 2.0.1
BuildArch:      noarch
%python_subpackages

%description
Command Line Interface Formulation Framework

%prep
%autosetup -p1 -n cliff-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# doesn't work with pytest atm
rm -v cliff/tests/test_commandmanager.py
%pytest cliff/tests

%files %{python_files}
%doc AUTHORS ChangeLog README.rst
%license LICENSE
%{python_sitelib}/cliff
%{python_sitelib}/cliff-%{version}.dist-info

%changelog
* Thu Jan  9 2025 Yunus Acar <yunus.acar@suse.com>
- update to 4.8.0:
  * Remove unnecessary shebangs
  * ruff: Enable pyupgrade rules
  * Migrate to ruff, ruff-format
  * Drop support for Python 3.8, add Python 3.12
  * pre-commit: Bump versions
  * Normalize columns given by '-c'/'--columns'
* Sun Jun  2 2024 Dirk Müller <dmueller@suse.com>
- update to 4.7.0:
  * Add fixtures explicitly in test requirements
  * tox: Use pre-commit for linter checks
  * Blacken code base
  * requirements: Bump minimums
* Sun Apr  7 2024 Dirk Müller <dmueller@suse.com>
- update to 4.6.0:
  * Test python 3.10 and 3.11
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 4.5.0:
  * Use importlib.metadata on Python 3.10+
* Thu Jan  4 2024 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Handle complex objects in yaml formatter better
  * Fix pre-commit issues
  * Autofit table output if stdout is a tty
  * Fix flake8 violation E721
  * Use upper-constraint in doc generation
  * Removing helper functions providing Python < 3.3
    compatibility
  * Strip trailing periods when getting description
  * Clarification of the algorithm used
  * columns: Useful \_\_str\_\_, \_\_repr\_\_ implementation
  * Add Python3 antelope unit tests
  * Removing brackets around tested conditional
  * Replace abc.abstractproperty with property and
    abc.abstractmethod
  * Remove final use of pkg\_resources
  * Defer loading PyYAML
  * Defer loading cmd2
  * requirements: Remove explicit python-subunit dependency
  * requirements: Remove explicit pbr dependency
  * requirements: Remove explicit pyparsing dependency
  * Update Python testing per Zed cycle testing runtime
  * Migrate Python 3.6/7 jobs to Python 3.8
  * Removing modindex link from docs
  * Add Python3 yoga unit tests
  * Automatically page interactive root help output
  * Colourise and automatically page help output
  * Update unit test to satisfy python3.10+
  * Handle SIGPIPE exit gracefully
  * Add conflict\_handler parameter as attribut in Command class
  * setup.cfg: Replace dashes with underscores
  * Replace getargspec with getfullargspec
  * setup.cfg: Replace dashes with underscores
  * Use py3 as the default runtime for tox
  * Add Python3 xena unit tests
- switch to singlespec
* Sun May  2 2021 cloud-devel@suse.de
- update to version 3.7.0
  - Add Python3 wallaby unit tests
  - Remove unicode from code
  - Exit gracefully on Ctrl-C
  - Update requirements
  - List setuptools under install_requires
  - change help action to use its own exception for exit
  - Remove Babel from lower-constraints.txt
  - Add '--sort-ascending', '--sort-descending' parameters
  - requirements: Uncap PrettyTable
  - Remove six
  - Remove lower-constraints
  - columns: Make 'FormattableColumn' comparable
  - Remove references to setuptools
  - Handle null values when sorting
  - Make 'FormattableColumn' comparable
  - Bump py37 to py38 in tox.ini
  - Update requirements URLs in tox config
  - Capturing argparse errors due to problem with cmd2
  - trivial: Remove references to Python 2.7
  - Document KeyboardInterrupt exit code
  - Add py38 package metadata
  - doc: Update bug tracker to storyboard
  - gitignore: Ignore reno artefacts
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 3.4.0
  - Migrate to stestr
  - Remove python3.5
  - drop mock from lower-constraints and requirements
  - switch to stevedore for loading entry points
  - Switch to newer openstackdocstheme version
  - Use unittest.mock instead of third party mock
  - Remove unneeded tests
  - Fix compatibility with new cmd2
  - Add Python3 victoria unit tests
  - Import command group support from osc-lib
  - Remove cap on cmd2
  - Stop to use the __future__ module.
* Tue May 12 2020 cloud-devel@suse.de
- update to version 3.1.0
  - Switch to Ussuri jobs
  - Add contributors link to readme
  - Fix nested argument groups with ignore conflict handler
  - [ussuri][goal] Drop python 2.7 support and testing
  - Allow finding command by partial name
  - Add autoprogram_cliff_app_dist_name config opt
  - adding missing releasenote for the drop of py27 support
  - Add an errexit attribute to InteractiveApp to exit on command errors
  - Re-add support for python 3.5
  - Modify the help message of `-c`/`--column` parameter
  - Stop wildcard importing argparse
* Wed Mar 11 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only build
* Fri Dec 20 2019 cloud-devel@suse.de
- update to version 2.16.0
  - Dropping the py35 testing
  - add python 3.7 unit test job
  - Remove dead files
  - OpenDev Migration Patch
  - Updates for OpenDev transition
  - Change openstack-dev to openstack-discuss
  - Pin cmd2 back to <0.9 on all versions
  - add argparse conflict handler "ignore"
  - Missing carriage return in some cases, using -f json
  - Add Python 3 Train unit tests
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 2.14.1
  - Use template for lower-constraints
  - add lib-forward-testing-python3 test job
  - import zuul job settings from project-config
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - Removed unused err variable
  - Don't try to run issubclass on non-classes
* Wed Mar  6 2019 cloud-devel@suse.de
- downgrade to version 2.13.0 to match rest of rocky based clients
* Thu Feb 28 2019 cloud-devel@suse.de
- update to version 2.14.0
  - sphinxext: Warn if namespace or command pattern invalid
  - fix tox python3 overrides
  - import zuul job settings from project-config
  - Remove the warning of getargspec removal
  - Zuul: Remove project name
  - Fix cmd2 doc URL
  - add lib-forward-testing-python3 test job
  - support cmd2 0.9.1 in interactive mode
  - update cmd2 dependency to handle py3 only versions
  - Build universal wheels
  - exclude cmd2 0.8.3 and update to 0.8.4
  - Align parsed() call with cmd2 versions >= 0.7.3
  - Removed unused err variable
  - switch documentation job to new PTI
  - add python 3.6 unit test job
  - Remove travis.yml
  - Assure executable name is kept when app is called as module
  - Updated from global requirements
  - add lower-constraints job
  - Don't try to run issubclass on non-classes
  - fix typos in documentation
* Tue Feb 13 2018 cloud-devel@suse.de
- update to version 2.11.0
  - Move doc requirements to doc/requirements.txt
  - Alias exit to cmd2's quit command to exit interactive shell
  - doc: Remove blank lines between term and definition
  - remove -s alias for --sort-columns
  - Replace legacy tips jobs with shiny new versions
  - Update .gitignore
  - Updated from global requirements
  - sphinxext: Support cliff application
  - Remove tox_install.sh and just pass -c in tox
  - do not require installing demo app to build docs
  - Remove empty files
  - add support for legacy command name translation
  - doc: Cleanup of demoapp doc
  - Generate demoapp CLI refernece
  - Fix codec error when format=csv
  - Use in-tree cliffdemo app for docs build
  - add bandit to pep8 job
  - Use assertIsNone(...) instead of assertIs(None,...)
  - Fix PEP8 in gate
  - Add ability to sort data by columns for list commands
* Wed Nov 22 2017 cloud-devel@suse.de
- update to version 2.9.1
  - doc: minor cleanup
  - trivial: Fix comments in sphinxext module
  - add actual column names to error msg
  - handle more varied top_level.txt files in distributions
  - Allow command hooks to make changes
  - Move comments up in [extras] section of setup.cfg
  - Update doc on Sphinx integration process
  - show the distribution providing the command in help output
  - Update and replace http with https for doc links
  - Make openstackdocstheme an optional doc dependency
  - Docs update for more-hooks
  - sphinxext: Correct issues with usage formatting
  - Fix regexp for detecting long options
  - Updates for stestr
  - Updated from global requirements
- Drop 0001-Make-openstackdocstheme-an-optional-doc-dependency.patch .
  Applied upstream
- Add _service and switch to openstack/rpm-packging spec template
* Mon Aug  7 2017 tbechtold@suse.com
- update to 2.8.0:
  * add tests for display command classes and hooks
  * Run hooks for DisplayCommandBase
  * add --fit-width option to table formatter
  * sphinxext: Add 'application' option to the autoprogram directive
  * use openstackdocstheme html context
  * switch from oslosphinx to openstackdocstheme
  * Fix erroneous line in command hook test
  * make smart help formatter test deterministic
  * remove references to distribute in the docs
  * add before and after hooks
  * add hook for get\_epilog
  * add hook for manipulating the argument parser
  * Updated from global requirements
  * pass the command name from HelpCommand
  * Adjust completenames tests for cmd2 0.7.3+
  * rearrange existing content to follow new standard
  * sphinext: Use metavar where possible
  * sphinxext: Use 'argparse.description', 'argparse.epilog'
  * sphinxext: Allow configuration of ignorable options
  * sphinxext: Generate better usage examples
  * add cmd\_name argument to CompleteCommand
  * Ensure python standard argparse module is loaded
  * Updated from global requirements
  * covert test suite to use testrepository
  * Updated from global requirements
  * Add smart help formatter for command parser
  * Add support for epilogs
  * Add 'autoprogram-cliff' Sphinx directive
  * .gitignore: Ignore eggs
  * Use Sphinx 1.5 warning-is-error
  * Update cmd2 fix to still work with 0.6.7
  * Remove support for py34
  * Fix broken test with cmd2 0.7.0
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Add newline if the output formatter is json
- Add 0001-Make-openstackdocstheme-an-optional-doc-dependency.patch
* Fri Feb 10 2017 tbechtold@suse.com
- update to 2.4.0:
  * Remove tox environments that no longer work
  * Fix command order
  * Show team and repo badges on README
  * Add print_empty parameter
  * ignore Command docstring when looking for descriptions
  * let the Command get its one-liner description from a class attribute
  * flake8 fix
  * Replace dashes and colons when using bash formatter
  * Show entire command in error message
  * Updated from global requirements
  * Updated from global requirements
  * Fix spelling mistake
  * Add Python 3.5 classifier and venv
  * Updated from global requirements
  * Changed the home-page link
  * Add Apache 2.0 license to source file
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Clean imports in code
  * [doc]Fix URL for 'setuptools entry points'
  * Fix a typo in comment
- Remove relax-sphinx-requirement.patch . No longer needed.
* Tue Oct  4 2016 tbechtold@suse.com
  update to version 2.2.0
  * Fixed broken link
  * pep8: fix F405 error
  * add formattable columns concept
  * command: make run() return take_action() value
  * Fix cliff URLs in doc and demoapp
  * Avoid ASCII encoding errors when output is redirected
  * Fix Command class doc typo
  * Remove announce.rst
  * Updated from global requirements
  * Add tests, cover more cases
* Thu Jul  7 2016 tbechtold@suse.com
- Switch to pypi.io as Source url
* Thu Jul  7 2016 tbechtold@suse.com
- update to 2.1.0:
  * Updated from global requirements
  * Update --max-width help
  * Add more test coverage for shell formatter
  * Add more test coverage for CSV formatter
  * Support multiple sub commands in completion
  * Factorize more test data
  * Factorize some test data
  * Factorize common test code
  * Factorize argparse importing
  * Updated from global requirements
  * Updated from global requirements
  * Add CLIFF_MAX_TERM_WIDTH envvar to complement --max-width
  * Fix prettytable.PrettyTable().max_width wrong usage
  * Fix AttributeError when entry point load failed
  * Distinguish no existed columns in ShowOne
  * Refactor HelpCommand
  * Updated from global requirements
  * Remove httplib2 from test-requirements.txt
  * Sync help message for --help
  * handle empty list in table formatter
  * Drop Python 2.6 support
  * Revert "app,command: disallow abbrev by default"
  * Fixes terminal_width on Windows
  * Updated from global requirements
  * remove openstack-common.conf
  * Add doc for deferred_help parameter
  * Fix pep8 failure
  * app,command: disallow abbrev by default
  * app: work-around abbrev
  * remove unnecessary dependency on argparse
  * Make verbose and quiet mutually exclusive
  * setup: fix Python versions classifiers
  * Don't import unused logging
  * Don't use non-existent method of Mock
  * Replace dashes with underscores in bash completion
  * Updated from global requirements
  * Resize columns to fit screen width
  * fix fuzzy search for same-distance case
  * Correct path to docs
  * only use unicodecsv for python 2.x
  * Fix test class docstring for py 3.5
- Adjust Requires and BuildRequires
* Wed Sep 16 2015 tbechtold@suse.com
- update to 1.15.0:
  * Replace '\r' with ' ' for prettytable
  * Implement a json formatter in cliff
  * Implement a yaml formatter in cliff
  * Updated from global requirements
  * Improve help messages
- Adjust Requires according to requirements.txt
* Fri Aug 21 2015 tbechtold@suse.com
- update to 1.14.0:
  * Add csv formatter test
  * Fix encoding issue with the default python csv output
  * Remove py26 as a default test from tox.ini
  * Set demo app up with deferred help
  * Add command fuzzy matching
  * Updated from global requirements
  * Remove requirements.txt from tox.ini
  * Updated from global requirements
  * Updated from global requirements
  * Allow subcommands to accept --help when using 'deferred_help'
  * Updated from global requirements
  * Fix logging config in demo app
  * Use base command for help test
  * Updated from global requirements
  * Include the automatically-generated changelog
  * Updated from global requirements
- Adjust Requires according to requirements.txt
- Refreshed relax-sphinx-requirement.patch
* Fri Jul 24 2015 seife+obs@b1-systems.com
- Fix build for RHEL7 by nulling test requirements
* Tue Jun 23 2015 dmueller@suse.com
- update to 1.13.0:
  * Fix object has no attribute debug error
  * Add some docs for list value formatter
  * Add value format for list command
  * Updated from global requirements
  * Remove run_cross_tests.sh
  * fix author contact details
  * Print help on help command
  * Do not check requirements when loading plugins
- add relax-sphinx-requirement.patch
* Tue Mar 10 2015 tbechtold@suse.com
- update to 1.10.1:
  * Document print_help_if_requested method
  * Allow to call initialize_app when running --help
  * Hide prompt in batch/pipe mode
  * Correct completion in interactive mode
  * Fix pep8 tests for lambda
  * Updated from global requirements
  * Fix git repo urls in tox.ini
  * Add deprecated attribute to commands
  * Workflow documentation is now in infra-manual
- Adjust Requires according to requirements.txt
* Thu Jan  8 2015 tbechtold@suse.com
- update to 1.9.0:
  * print the real error cmd argument
  * Updated from global requirements
  * Update link to docs in README
  * Bring doc build up to standard
  * Add pbr to installation requirements
  * Add more detail to the README
  * Updated from global requirements
  * Add docs environment to tox.ini
  * mock.assert_called_once() is not a valid method
  * Work toward Python 3.4 support and testing
  * warn against sorting requirements
- Adjust Requires according to requirements.txt
- Adjust BuildRequires accroding to test-requirements.txt
- Fix build path for documentation
* Sat Sep 13 2014 tbechtold@suse.com
- update to 1.7.0:
  * Add release notes for 1.7.0
  * Fix stable integration tests
  * Updated from global requirements
  * Clean up default tox environment list
  * Do not allow wheels for stable tests
  * Set the main logger name to match the application
  * CSV formatter should use system-dependent line ending
  * Make show option compatible with Python 2.6
  * Use six.add_metaclass instead of __metaclass__
  * fixed typos found by RETF rules
  * The --variable option to shell format is redundant
  * Expose load_commands publicly
  * Fix wrong method name assert_called_once
  * Updated from global requirements
  * Fix pep8 failures on rule E265
* Thu Jun 26 2014 dmueller@suse.com
- update to 1.6.1:
  * Remove PrettyTable from documentation requirements
  * Fix a bug in ShellFormatter's escaping of double quotes in strings
  * Import run_cross_tests.sh from oslo-incubator
  * add doc requirements to venv
  * Add max-width support for table formatter
  * Add value only output formattter
  * Update readme with links to bug tracker and source
  * Move pep8 dependency into pep8 tox test
  * Fix doc build with Python 2.6.x
  * Fix interactive mode with command line args
  * Update .gitreview after repo rename
  * Escape double quotes in shell formatter
  * Add unit test for shell formatter
  * Rename private attribute to avoid conflict
  * Sync with global requirements
  * Add integration tests with known consumers
  * update history for previous change
  * Make the formatters a private part of the command
- 0001-Fix-doc-build-with-Python-2.6.x.patch, 0001-Move-pep8-dependency-into-pep8-tox-test.patch,
  remove-distribute-dep.patch: Merged upstream
* Thu Feb 13 2014 dmueller@suse.com
- add 0001-Move-pep8-dependency-into-pep8-tox-test.patch: remove global pep8 dependency
* Tue Jan 21 2014 dmueller@suse.com
- update to 1.5.2:
  * Fix the arguments passed to commands when they are instantiated to
  pull out help.
  * Add bash command completion.
  * Use stevedore to load formatter plugins
  * Use pbr for packaging
- add remove-distribute-dep.patch: remove distribute dependency
- add 0001-Fix-doc-build-with-Python-2.6.x.patch: Fix build with python 2.6
* Fri Sep 27 2013 dmueller@suse.com
- update to 1.4.5:
  * Update the pyparsing dependency to a version that supports both
  Python 2 and Python 3.
  * Add PyPy testing.
- remove patches that went upstream:
  * remove 0001-Require-pyparsing-2.0.1.patch
  * remove relax-cmd2-requires.diff
- fix requires
* Tue Sep 17 2013 speilicke@suse.com
- Add 0001-Require-pyparsing-2.0.1.patch: Allow running with pyparsing>=2.0.1
* Mon Sep  9 2013 dmueller@suse.com
- add relax-cmd2-requires.diff: Allow 0.6.6.1 or newer
* Tue Sep  3 2013 dmueller@suse.com
- update to 1.4.4:
  - Provide better error handling for unknown commands run from the
  command line. (Contributed by Christophe Chauvet.)
* Thu Jun 27 2013 speilicke@suse.com
- Update to version 1.4:
  + Upstream provides no changelog
* Fri May  3 2013 speilicke@suse.com
- Update to version 1.3.3:
  + Upstreamed:
  - 0001-Restore-compatibility-with-Prettytable-0.7.2.patch
  - ignore-cmd2-requires.diff:
* Thu May  2 2013 dmueller@suse.com
- add 0001-Restore-compatibility-with-Prettytable-0.7.2.patch
* Tue Apr 30 2013 dmueller@suse.com
- add ignore-cmd2-requires.diff:
  loosen cmd2 version requires
* Thu Apr 25 2013 dmueller@suse.com
- update to 1.3.2:
  - Add ``convert_underscores`` parameter to ``CommandManager`` ``__init__``
    method to allow underscores to be used in command names. This optional
    argument is defaulted to True to maintain current behavior.
  (contributed by Joe Server)
  - Use flake8_ for style checking.
  - Relax version requirement for PrettyTable dependency to allow
    point releases of 0.7.
* Wed Apr 24 2013 dmueller@suse.com
- buildrequire the right mock version
* Mon Mar 18 2013 dmueller@suse.com
- tighten requires on pyparsing
* Wed Mar 13 2013 dmueller@suse.com
- add prettytable-0.7x.diff:
  - Be compatible with PrettyTable 0.7
- tighten rpm dependencies
* Tue Mar 12 2013 dmueller@suse.com
- Update to 1.3.1:
  - Sort list of commands in interactive help mode.
  - Fix a dependency issue with PyParsing until the cmd2 package can
    release an update setting the version of its dependency based on the
    Python version.
* Fri Nov  9 2012 saschpe@suse.de
- Update to version 1.3:
  + Upstream provides no changelog
- Split out documentation
- Really run testsuite
* Fri Jul 27 2012 saschpe@suse.de
- Add needed runtime requirements
- Run testsuite
- Set license to Apache-2.0
* Fri Jul 27 2012 cthiel@suse.com
- initial package (version 1.0)
